;; Generated package description from zuul.el  -*- no-byte-compile: t -*-
(define-package "zuul" "0.4.0.0.20230111.174756" "Interface to Zuul" '((emacs "27.1") (project "0.8.1")) :commit "0208db02df6b7a5ceda7c6d5524c15bf1c4d61b4" :authors '(("Niklas Eklund" . "niklas.eklund@posteo.net")) :maintainer '("zuul.el Development" . "~niklaseklund/zuul.el@lists.sr.ht") :keywords '("convenience" "tools") :url "https://sr.ht/~niklaseklund/zuul.el")
